@@ -7,7 +7,7 @@
 # of the license.
 
 __author__ = 'Martin Pitt'
-__email__  = 'martin.pitt@ubuntu.com'
+__email__ = 'martin.pitt@ubuntu.com'
 __copyright__ = '(c) 2012 Canonical Ltd.'
 __license__ = 'LGPL 3+'
 
@@ -42,7 +42,7 @@ class TestAPI(dbusmock.DBusTestCase):
 
         self.obj_test = self.dbus_con.get_object('org.freedesktop.Test', '/')
         self.dbus_test = dbus.Interface(self.obj_test, 'org.freedesktop.Test.Main')
-        self.dbus_mock = dbus.Interface(self.obj_test, 'org.freedesktop.DBus.Mock')
+        self.dbus_mock = dbus.Interface(self.obj_test, dbusmock.MOCK_IFACE)
         self.dbus_props = dbus.Interface(self.obj_test, dbus.PROPERTIES_IFACE)
 
     def tearDown(self):
@@ -90,15 +90,13 @@ assert args[2] == 5
 ''')
         self.assertEqual(self.dbus_test.Do(-1, ['/foo'], 5), None)
 
-
     def test_methods_on_other_interfaces(self):
         '''methods on other interfaces'''
 
         self.dbus_mock.AddMethod('org.freedesktop.Test.Other', 'OtherDo', '', '', '')
-        self.dbus_mock.AddMethods('org.freedesktop.Test.Other', 
-                                 [('OtherDo2', '', '', ''),
-                                  ('OtherDo3', 'i', 'i', 'ret = args[0]'),
-                                 ])
+        self.dbus_mock.AddMethods('org.freedesktop.Test.Other',
+                                  [('OtherDo2', '', '', ''),
+                                   ('OtherDo3', 'i', 'i', 'ret = args[0]')])
 
         # should not be on the main interface
         self.assertRaises(dbus.exceptions.DBusException,
@@ -152,7 +150,6 @@ assert args[2] == 5
         obj1 = self.dbus_con.get_object('org.freedesktop.Test', '/obj1')
         dbus_sub = dbus.Interface(obj1, 'org.freedesktop.Test.Sub')
         dbus_props = dbus.Interface(obj1, dbus.PROPERTIES_IFACE)
-        dbusmock = dbus.Interface(obj1, 'org.freedesktop.DBus.Mock')
 
         # check properties
         self.assertEqual(dbus_props.Get('org.freedesktop.Test.Sub', 'state'), 'online')
@@ -161,7 +158,8 @@ assert args[2] == 5
                          {'state': 'online', 'cute': True})
 
         # add new method
-        dbusmock.AddMethod('', 'Do', '', 's', 'ret = "hello"')
+        obj1.AddMethod('', 'Do', '', 's', 'ret = "hello"',
+                       dbus_interface=dbusmock.MOCK_IFACE)
         self.assertEqual(dbus_sub.Do(), 'hello')
 
     def test_add_object_existing(self):
@@ -223,12 +221,12 @@ assert args[2] == 5
                           dbus.Int32(2, variant_level=1))
 
         self.dbus_mock.AddProperty('org.freedesktop.Test.Main',
-                                  'version',
-                                  dbus.Int32(2, variant_level=1))
+                                   'version',
+                                   dbus.Int32(2, variant_level=1))
         # once again on default interface
         self.dbus_mock.AddProperty('',
-                                  'connected',
-                                  dbus.Boolean(True, variant_level=1))
+                                   'connected',
+                                   dbus.Boolean(True, variant_level=1))
 
         self.assertEqual(self.dbus_props.Get('org.freedesktop.Test.Main', 'version'), 2)
         self.assertEqual(self.dbus_props.Get('org.freedesktop.Test.Main', 'connected'), True)
@@ -243,8 +241,8 @@ assert args[2] == 5
 
         # add property to different interface
         self.dbus_mock.AddProperty('org.freedesktop.Test.Other',
-                                  'color',
-                                  dbus.String('yellow', variant_level=1))
+                                   'color',
+                                   dbus.String('yellow', variant_level=1))
 
         self.assertEqual(self.dbus_props.GetAll('org.freedesktop.Test.Main'),
                          {'version': 4, 'connected': True})
